@@ -1,4 +1,11 @@
-
+#' @title Determine whether a test is running on CRAN under macos
+#'
+#' @description We are currently getting failed unit tests on CRAN under macos, while the package works under MacOS on both <https://builder.r-hub.io/> and on our MacOS machines. This is because the package file cache does not work on CRAN, as the HOME is mounted read-only on the CRAN test systems. So we have to skip the tests that require optional data under MacOS on CRAN.
+#'
+#' @return logical, whether a test is running on CRAN under MacOS
+tests_running_on_cran_under_macos <- function() {
+  return(tolower(Sys.info()[["sysname"]]) == 'darwin' && !identical(Sys.getenv("NOT_CRAN"), "true"));
+}
 
 
 
@@ -11,6 +18,7 @@ test_that("Our demo surface file can be read using read.fs.surface", {
   skip_if_not(file.exists(surface_file), message="Test data missing.") ;
 
   surf = read.fs.surface(surface_file);
+  expect_true(is.fs.surface(surf));
   known_vertex_count = 149244;
   known_face_count = 298484;
 
@@ -43,6 +51,7 @@ test_that("Vertex connectivity in the demo surface file is as expected from refe
   skip_if_not(file.exists(surface_file), message="Test data missing.");
 
   surf = read.fs.surface(surface_file);
+  expect_true(is.fs.surface(surf));
 
   # This test assures that the vertices are connected as defined in the reference implementation.
   expect_equal(surf$faces[1,], c(0, 1, 5) + 1);     # the +1 is because R using 1-based indexing
@@ -54,6 +63,7 @@ test_that("Vertex connectivity in the demo surface file is as expected from refe
   expect_equal(surf$vertices[1000,], c(-5.2788, -103.5765, 19.6616), tolerance=1e-2);
 })
 
+
 test_that("The vertices of a face are close to each other", {
   # Checks for bug in issue #8: freesurfer surface import - row-major/column-major order
 
@@ -66,6 +76,8 @@ test_that("The vertices of a face are close to each other", {
 
   surf = read.fs.surface(surface_file);
 
+  expect_true(is.fs.surface(surf));
+
   # Test that the distance between the vertices of a face is small. For brain surface meshes, the
   # coords are given in mm and the resolution is quite high. It is definitely sane to request that
   # the vertices should not be more than 2 mm apart:
@@ -86,7 +98,8 @@ test_that("The lh.white of Bert can be read using read.fs.surface", {
   skip_if_not(file.exists(surface_file), message="Test data missing.");
 
   surface_file = system.file("extdata", "bert.lh.white", package = "freesurferformats", mustWork = TRUE)
-  surf = read.fs.surface(surface_file)
+  surf = read.fs.surface(surface_file);
+  expect_true(is.fs.surface(surf));
   known_vertex_count_bert = 133176;
   known_face_count_bert = 266348;
 
@@ -117,3 +130,26 @@ test_that("The lh.white of Bert can be read using read.fs.surface", {
   expect_equal(surf$vertices[100,], c(-12.234, -100.672, 0.129), tolerance=1e-2);
   expect_equal(surf$vertices[1000,], c(-18.8, -97.6, -16.8), tolerance=1e-2);
 })
+
+
+test_that("A surface file in FreeSurfer ASCII format can be read using read.fs.surface", {
+
+  fsasc_surface_file = system.file("extdata", "lh.tinysurface.asc", package = "freesurferformats", mustWork = TRUE);
+  surf = read.fs.surface(fsasc_surface_file);
+  expect_true(is.fs.surface(surf));
+  known_vertex_count = 5L;
+  known_face_count = 3L;
+
+
+  expect_equal(nrow(surf$vertices), known_vertex_count);
+  expect_equal(ncol(surf$vertices), 3);      # the 3 coords (x,y,z)
+  expect_equal(typeof(surf$vertices), "double");
+
+  expect_equal(nrow(surf$faces), known_face_count);
+  expect_equal(ncol(surf$faces), 3);      # the 3 vertex indices
+  expect_equal(typeof(surf$faces), "integer");
+
+  # Check whether vertex indices were incremented properly
+  num_faces_with_index_zero = sum(surf$faces==0);
+  expect_equal(num_faces_with_index_zero, 0);
+})
